# KFWX Data Analysis Tool

> This is a module that automatically analyzes data for assays. 

## Tools available
1. Membrane Potential
2. NADH Redox
3. H2O2
4. Membrane Potential Merge
5. NADH Redox Merge
6. H2O2 Merge

## Using the data analysis tools (tools 1-3)
1. Place the raw data files (.txt) to be analyzed in a folder.
2. Open the command line
3. Navigate to the folder 
    * e.g. if folder path is users/data_analysis, then type the command "cd users/data_analysis" without quotations
4. Type command "python -m kfwx" without quotations to run

## Using merge tools (tools 4-6)
1. Place the excel files (.xlsx) to be merged in a folder.
2. Open the command line
3. Navigate to the folder 
    * e.g. if folder path is users/data_analysis, then type the command "cd users/data_analysis" without quotations
4. Type command "python -m kfwx" without quotations to run
